@@ -56,9 +56,9 @@ class Cli(object):
         submit_parser.add_argument('-p', '--profile', action='append', type=str,
                                    help="specify the profiles to use "
                                    "(can be given multiple times)")
-        submit_parser.add_argument('--all-profiles', action='store_true', 
+        submit_parser.add_argument('--all-profiles', action='store_true',
                                    help="process all the available profiles")
-        submit_parser.add_argument('-t', '--template-vars', action='append', 
+        submit_parser.add_argument('-t', '--template-vars', action='append',
                                    type=str, help="set 'field:value' "
                                    "template variables/values "
                                    "(can be given multiple times")
@@ -75,6 +75,8 @@ class Cli(object):
         submit_parser.add_argument('--priority',
                                    choices=['high', 'medium', 'low'],
                                    help="Set the job priority"),
+        submit_parser.add_argument('--live', action='store_true',
+                                   help="show job output live")
         submit_parser.add_argument('--check-image-url', action='store_true',
                                    help="Check that the image url exists before "
                                    "submitting job")
@@ -218,7 +220,7 @@ class Cli(object):
         results_parser.set_defaults(func=results)
 
         # Jobdef (show job definition)
-        jobdef_parser = subparsers.add_parser('jobdef', 
+        jobdef_parser = subparsers.add_parser('jobdef',
                                               help="Show job definition file")
         jobdef_parser.add_argument('job_ids',  nargs='+', type=str,
                                    metavar='JOB_ID',
@@ -231,6 +233,8 @@ class Cli(object):
         queue_parser.add_argument('-n', '--name', action='append', type=str,
                                   default=[], help="filter jobs with NAME "
                                   "(can be given multiple times)")
+        queue_parser.add_argument('-u', '--user', type=str,
+                                  help="filter jobs with user NAME")
         queue_parser.add_argument('-d', '--device', action='append', type=str,
                                   help="filter jobs running in DEVICE "
                                   "(can be given multiple times)")
@@ -253,6 +257,8 @@ class Cli(object):
         cleanqueue_parser.add_argument('-n', '--name', action='append', type=str,
                                        default=[], help="clean jobs with NAME "
                                        "(can be given multiple times)")
+        cleanqueue_parser.add_argument('-u', '--user', type=str,
+                                       help="clean jobs with user NAME")
         cleanqueue_parser.add_argument('-d', '--device', action='append', type=str,
                                        help="clean jobs running in DEVICE "
                                        "(can be given multiple times)")
